@@ -20,6 +20,9 @@ class TotalSizeReference(Reference):
             positions = SequentialRangeList(itertools.chain(*lists))
             result = positions.max_stop()  # total_size calculation
         else:
+            # For each field we do the following and then take the maximum:
+            #   We fetch the field's unpack size from unpack_ref (should already be cached).
+            #   We then fetch the field's absolute position and calculate the byte offset from that.
             result = max(self._unpack_position_list_for_field(ctx, field) for field in ctx.fields)
 
         assert result is not None
@@ -27,7 +30,7 @@ class TotalSizeReference(Reference):
 
     def _unpack_position_list_for_field(self, ctx, field):
         _, size = field.unpack_ref.deref(ctx)
-        result = field.unpack_absolute_position_ref.unpack_position_ref.deref(ctx).byte_offset(size)
+        result = field.unpack_absolute_position_ref.deref(ctx).byte_offset(size)
         return result
 
     def __safe_repr__(self):
